@@ -300,7 +300,7 @@ typedef struct GentooSystemConfigData
  * info before setting stuff too.
  *
  */
-void *nm_system_device_get_system_config (NMDevice *dev)
+void *nm_system_device_get_system_config (NMDevice *dev, NMData *app_data)
 {
 	char		*cfg_file_path = NULL;
 	FILE		*file = NULL;
@@ -583,3 +583,14 @@ gboolean nm_system_should_modify_resolv_conf (void)
 {
 	return TRUE;
 }
+
+/*
+ * nm_system_get_mtu
+ *
+ * Return a user-provided or system-mandated MTU for this device or zero if
+ * no such MTU is provided.
+ */
+guint32 nm_system_get_mtu (NMDevice *dev)
+{
+	return 0;
+}
